@@ -35,10 +35,9 @@ def set_foreign_key_constraint(dbapi_connection, connection_record):
 
 def setup_in_memory_db():
     # Ensure we are using in-memory SQLite database, and creating tables.
-    repositories.CONF.set_override("sql_connection", "sqlite:///:memory:",
-                                   enforce_type=True)
-    repositories.CONF.set_override("db_auto_create", True, enforce_type=True)
-    repositories.CONF.set_override("debug", True, enforce_type=True)
+    repositories.CONF.set_override("sql_connection", "sqlite:///:memory:")
+    repositories.CONF.set_override("db_auto_create", True)
+    repositories.CONF.set_override("debug", True)
 
     # Ensure the connection is completely closed, so any previous in-memory
     # database can be removed prior to starting the next test run.
@@ -197,6 +196,21 @@ def create_container_consumer_meta(container=None, parsed_request=None,
     return container_consumer_meta
 
 
+def create_secret_consumer(secret=None, service="service",
+                           resource_id="resource_id",
+                           resource_type="resource_type", session=None):
+    consumer = models.SecretConsumerMetadatum(
+        secret_id=secret.id,
+        project_id=secret.project_id,
+        service=service,
+        resource_type=resource_type,
+        resource_id=resource_id,
+    )
+    repo = repositories.get_secret_consumer_repository()
+    repo.create_from(consumer, session=session)
+    return consumer
+
+
 def create_certificate_authority(project=None, parsed_ca_in=None,
                                  session=None):
     if not parsed_ca_in:
